# Mickzaa 
It takes user age as an input to compare with Mickzaa age.

## Installation
```pip install mickzaa-age```

## How to use it?
Open terminal and type mickzaa and then input your age

## License
© 2021 Mickzaa